@@ -17,12 +17,27 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 请求未授权。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
 # 告警策略通知模板已经绑定到了某个告警策略上。
 FAILEDOPERATION_BINDEDALARM = 'FailedOperation.BindedAlarm'
 
+# 桶内无相应前缀文件，请使用正确的桶、文件前缀和压缩方式。
+FAILEDOPERATION_BUCKETNOFILE = 'FailedOperation.BucketNoFile'
+
+# 文件解压缩失败，请选择正确的压缩方式。
+FAILEDOPERATION_DECOMPRESSFILE = 'FailedOperation.DecompressFile'
+
+# 文件下载失败，请稍后再试。
+FAILEDOPERATION_DOWNLOADFILE = 'FailedOperation.DownLoadFile'
+
+# 获取文件列表失败，请稍后再试。
+FAILEDOPERATION_GETLISTFILE = 'FailedOperation.GetListFile'
+
 # 检索日志触发最大条数限制。
 FAILEDOPERATION_GETLOGREACHLIMIT = 'FailedOperation.GetlogReachLimit'
 
@@ -71,6 +86,9 @@ FAILEDOPERATION_TAGQPSLIMIT = 'FailedOperation.TagQpsLimit'
 # 日志主题已关闭。
 FAILEDOPERATION_TOPICCLOSED = 'FailedOperation.TopicClosed'
 
+# topic创建中
+FAILEDOPERATION_TOPICCREATING = 'FailedOperation.TopicCreating'
+
 # 日志主题已隔离。
 FAILEDOPERATION_TOPICISOLATED = 'FailedOperation.TopicIsolated'
 
@@ -98,6 +116,12 @@ INVALIDPARAMETER_CONFIGCONFLICT = 'InvalidParameter.ConfigConflict'
 # 无效的Content。
 INVALIDPARAMETER_CONTENT = 'InvalidParameter.Content'
 
+# 数据加工任务冲突。
+INVALIDPARAMETER_DATAFROMTASKCONFLICT = 'InvalidParameter.DataFromTaskConflict'
+
+# 数据加工任务不存在。
+INVALIDPARAMETER_DATAFROMTASKNOTEXIST = 'InvalidParameter.DataFromTaskNotExist'
+
 # 数据库唯一键冲突。
 INVALIDPARAMETER_DBDUPLICATION = 'InvalidParameter.DbDuplication'
 
@@ -110,6 +134,9 @@ INVALIDPARAMETER_INVALIDINDEXRULEFORSEARCHLOW = 'InvalidParameter.InValidIndexRu
 # 指定日志主题已经存在索引规则。
 INVALIDPARAMETER_INDEXCONFLICT = 'InvalidParameter.IndexConflict'
 
+# 无效的数据加工语句。
+INVALIDPARAMETER_INVALIDETLCONTENT = 'InvalidParameter.InvalidEtlContent'
+
 # 相同的日志集已存在。
 INVALIDPARAMETER_LOGSETCONFLICT = 'InvalidParameter.LogsetConflict'
 
@@ -134,6 +161,9 @@ LIMITEXCEEDED_CONFIG = 'LimitExceeded.Config'
 # 创建日志导出任务数量超出限制。
 LIMITEXCEEDED_EXPORT = 'LimitExceeded.Export'
 
+# 索引操作超过频率限制。
+LIMITEXCEEDED_INDEXOPERATING = 'LimitExceeded.IndexOperating'
+
 # 并发查询超过限制，单topic并发最大值15。
 LIMITEXCEEDED_LOGSEARCH = 'LimitExceeded.LogSearch'
 
@@ -209,6 +239,9 @@ OPERATIONDENIED_TOPICHASDATAFORMTASK = 'OperationDenied.TopicHasDataFormTask'
 # topic绑定了函数投递。
 OPERATIONDENIED_TOPICHASDELIVERFUNCTION = 'OperationDenied.TopicHasDeliverFunction'
 
+# topic配置有外部数据源配置，不能删除
+OPERATIONDENIED_TOPICHASEXTERNALDATASOURCECONFIG = 'OperationDenied.TopicHasExternalDatasourceConfig'
+
 # topic绑定了scheduleSql任务。
 OPERATIONDENIED_TOPICHASSCHEDULESQLTASK = 'OperationDenied.TopicHasScheduleSqlTask'
 
@@ -227,6 +260,9 @@ RESOURCENOTFOUND_ALARMNOTICENOTEXIST = 'ResourceNotFound.AlarmNoticeNotExist'
 # 指定的采集规则配置不存在。
 RESOURCENOTFOUND_CONFIGNOTEXIST = 'ResourceNotFound.ConfigNotExist'
 
+# 数据加工任务不存在。
+RESOURCENOTFOUND_DATAFROMTASKNOTEXIST = 'ResourceNotFound.DataFromTaskNotExist'
+
 # 日志导出不存在。
 RESOURCENOTFOUND_EXPORTNOTEXIST = 'ResourceNotFound.ExportNotExist'
 
